/* This file is part of VisualDFT.
 *
 * VisualDFT is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * VisualDFT is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with VisualDFT; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package ch.educeth.visualdft;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JFrame;
import javax.swing.ImageIcon;
import javax.swing.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.lang.Math;

/**
 * Das PresetButtonPanel (abgeleitet von JPanel) erzeugt das fenster 
 * mit den presets (signale wie z.b. sawtooth). Zudem sind auch die betreffenden
 * listeners hier zu finden.
 */


public class PresetButtonPanel extends JPanel
					{

    private JButton flatButton,sinusButton,squareButton,sawtoothButton,
            triangleButton,randomButton;


    private DftRoot DRoot;

    private TitledBorder titleBorder;

    public PresetButtonPanel(DftRoot DRootA) {
     	this.DRoot=DRootA;

	titleBorder = BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(), 
			" P R E S E T S ");

	ImageIcon squareButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/square.gif"));
	ImageIcon sinusButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/sinus.gif"));
	ImageIcon randomButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/random.gif"));
	ImageIcon triangleButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/triangle.gif"));
	ImageIcon sawtoothButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/sawtooth.gif"));
	ImageIcon flatButtonIcon = new ImageIcon(PresetButtonPanel.class.getResource("images/flat.gif"));


        squareButton = new JButton("Square", squareButtonIcon);
	squareButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        squareButton.setHorizontalTextPosition(AbstractButton.CENTER);

	sawtoothButton = new JButton("Sawtooth", sawtoothButtonIcon);
        sawtoothButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        sawtoothButton.setHorizontalTextPosition(AbstractButton.CENTER);

	randomButton = new JButton("Random", randomButtonIcon);
        randomButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        randomButton.setHorizontalTextPosition(AbstractButton.CENTER);

	sinusButton = new JButton("Sinus", sinusButtonIcon);
        sinusButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        sinusButton.setHorizontalTextPosition(AbstractButton.CENTER);

     	triangleButton = new JButton("Triangle", triangleButtonIcon);
        triangleButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        triangleButton.setHorizontalTextPosition(AbstractButton.CENTER);

    	flatButton = new JButton("Flat", flatButtonIcon);
        flatButton.setVerticalTextPosition(AbstractButton.BOTTOM);
        flatButton.setHorizontalTextPosition(AbstractButton.CENTER);
        
	


        flatButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
		int i;
		for (i=0; i<DRoot.ANZ_SAMPLES; i++){
		DRoot.setAmplTimePoint(i,0.0d);
		}
		DRoot.dftForward();
		DRoot.redrawall();

	    }
        });
        sinusButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
		int i;

		for (i=0; i<(DRoot.ANZ_SAMPLES/2+1); i++){
            	DRoot.setAmplFreqTupple(i,0.0d,0.0d);
		}
		DRoot.setAmplFreqTupple(1,0.0d,0.8d);

		DRoot.dftInverse();
		DRoot.redrawall();
            }
        });
      	squareButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
		int i;
		for (i=0;  i< 5; i++){DRoot.setAmplTimePoint(i,-0.7d);}
		for (i=5;  i<15; i++){DRoot.setAmplTimePoint(i,0.7d);}
		for (i=15; i<20; i++){DRoot.setAmplTimePoint(i,-0.7d);}

		DRoot.dftForward();
		DRoot.redrawall();
            }
        });
        sawtoothButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
		int i;
		for (i=0 ; i<10; i++){ DRoot.setAmplTimePoint(i,i*0.075+0.05); }
		for (i=10; i<20; i++){ DRoot.setAmplTimePoint(i,(i-10)*0.075-0.7); }
		DRoot.dftForward();
		DRoot.redrawall();            	
            }
        });
      	triangleButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
       
		int i;
		for (i=0; i<5; i++){ DRoot.setAmplTimePoint(i,i*0.17); }
		for (i=5; i<15; i++){ DRoot.setAmplTimePoint(i,0.65- (i-5)*0.16 ); }
		for (i=15; i<20; i++){ DRoot.setAmplTimePoint(i,(i-15)*0.15-0.75); }
		DRoot.dftForward();
		DRoot.redrawall();  
     
            }
        });
        randomButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
   
	    	int i;
		for(i=0; i<20 ; i++){ DRoot.setAmplTimePoint(i,1.4d* Math.random() -0.7d );}
		DRoot.dftForward();
		DRoot.redrawall();  
            }
        });


        //Add Components to this container, using the default FlowLayout. 
	setLayout(new GridLayout(2,3,5,5));
        add(flatButton);
        add(sinusButton);
        add(squareButton);
	add(sawtoothButton);
        add(triangleButton);
	add(randomButton);
	setBorder(titleBorder);
    }

}